# cmIF fork: jinxIF version 0.0.0

Author: engje, bue

Date: 2020-11-01

License: GPLv3

Language: Python3

Description: jinxIF is a fork from Jennifer Eng's original cmIF mplex_image software library (https://gitlab.com/engje/cmif).
    cmIF is a Python3 library for automated image processing and analysis of multiplex immunofluorescence images.

